<?php

/**
 * @file
 * Form functions for the admin area.
 */

/**
 * Settings form to set the password only login user.
 *
 * @see passwd_only_admin_submit()
 */
function passwd_only_admin() {
  $form = array();

  $uid = variable_get('passwd_only_user');

  if ($uid) {
    $user = user_load($uid);
    $user_name = $user->name;
  }
  else {
    $user_name = '';
  }

  $form['user'] = array(
    '#type' => 'textfield',
    '#title' => t('Select a password only login user'),
    '#description' => t('Select a user to login in the password only login forms.'),
    '#size' => 60,
    '#maxlength' => 60,
    '#autocomplete_path' => 'user/autocomplete',
    '#default_value' => $user_name,
    '#required' => TRUE,
  );

  if (!empty($uid)) {
    $form['change_password'] = array(
      '#type' => 'item',
      '#title' => t('Change password'),
      '#markup' => l(t('Go to the password only login user.'), 'user/' . $uid . '/edit'),
    );
  }

  $form['description'] = array(
    '#type' => 'textarea',
    '#title' => t('Description'),
    '#description' => t('This description text is shown on the password only login form.'),
    '#default_value' => variable_get('passwd_only_description', ''),
  );

  $form['actions'] = array(
    '#type' => 'actions',
  );

  $form['actions']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );

  $form['#validate'][] = 'passwd_only_admin_validate';
  $form['#submit'][] = 'passwd_only_admin_submit';

  return system_settings_form($form);
}

/**
 * Validate callback for passwd_only_admin().
 *
 * @see passwd_only_admin()
 */
function passwd_only_admin_validate($form, &$form_state) {
  $account = user_load_by_name($form_state['values']['user']);
  if ($account->uid == 1) {
    form_set_error('user', t('"@name" is the root user account (User-ID 1). It is not secure to use this account with Password Only Login. Please select another user account.', array('@name' => format_username($account))));
  }
}

/**
 * Submit callback for passwd_only_admin().
 *
 * @see passwd_only_admin()
 */
function passwd_only_admin_submit($form, &$form_state) {
  variable_set('passwd_only_description', $form_state['values']['description']);
  passwd_only_set_user($form_state['values']['user']);
}
